@@ -10,7 +10,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2018 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -26,26 +26,6 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* = = = START-STATIC-FORWARD = = = */
-static size_t
-stringify_for_sh(char * pzNew, uint_t qt, char const * pzDta);
-
-static SCM
-shell_stringify(SCM obj, uint_t qt);
-
-static int
-sub_count(char const * haystack, char const * needle);
-
-static void
-do_substitution(
-    char const * src_str,
-    ssize_t      str_len,
-    SCM          match,
-    SCM          repl,
-    char **      ppz_res,
-    ssize_t *    res_len);
-/* = = = END-STATIC-FORWARD = = = */
-
 static size_t
 stringify_for_sh(char * pzNew, uint_t qt, char const * pzDta)
 {
@@ -110,10 +90,10 @@ stringify_for_sh(char * pzNew, uint_t qt, char const * pzDta)
 static SCM
 shell_stringify(SCM obj, uint_t qt)
 {
-    char*  pzNew;
+    char * pzNew;
     size_t dtaSize = 3;
-    char*  pzDta   = ag_scm2zchars(obj, "AG Object");
-    char*  pz      = pzDta;
+    char * pzDta   = ag_scm2zchars(obj, "AG Object");
+    char * pz      = pzDta;
 
     for (;;) {
         char c = *(pz++);
@@ -135,7 +115,7 @@ shell_stringify(SCM obj, uint_t qt)
     dtaSize = stringify_for_sh(pzNew, qt, pzDta);
 
     {
-        SCM res = AG_SCM_STR2SCM(pzNew, dtaSize);
+        SCM res = scm_from_latin1_stringn(pzNew, dtaSize);
         AGFREE(pzNew);
         return res;
     }
@@ -178,10 +158,10 @@ do_substitution(
     char **      ppz_res,
     ssize_t *    res_len)
 {
-    char* pzMatch  = ag_scm2zchars(match, "match text");
-    char* rep_str  = ag_scm2zchars(repl,  "repl text");
-    int   mark_len = (int)AG_SCM_STRLEN(match);
-    int   repl_len = (int)AG_SCM_STRLEN(repl);
+    char * pzMatch  = ag_scm2zchars(match, "match text");
+    char * rep_str  = ag_scm2zchars(repl,  "repl text");
+    int    mark_len = (int)scm_c_string_length(match);
+    int    repl_len = (int)scm_c_string_length(repl);
 
     {
         int ct = sub_count(src_str, pzMatch);
@@ -216,23 +196,22 @@ do_substitution(
     }
 }
 
-
-/*
+/**
  *  Recursive routine.  It calls itself for list values and calls
  *  "do_substitution" for string values.  Each substitution will
  *  be done in the order found in the tree walk of list values.
  *  The "match" and "repl" trees *must* be identical in structure.
  */
-LOCAL void
+static void
 do_multi_subs(char ** ppzStr, ssize_t * pStrLen, SCM match, SCM repl)
 {
-    char* pzStr = *ppzStr;
-    char* pzNxt = pzStr;
+    char * pzStr = *ppzStr;
+    char * pzNxt = pzStr;
 
     /*
      *  Loop for as long as our list has more entries
      */
-    while (! AG_SCM_NULLP(match)) {
+    while (! scm_is_null(match)) {
         /*
          *  "CAR" is the current value, "CDR" is rest of list
          */
@@ -242,7 +221,7 @@ do_multi_subs(char ** ppzStr, ssize_t * pStrLen, SCM match, SCM repl)
         match = SCM_CDR(match);
         repl  = SCM_CDR(repl);
 
-        if (AG_SCM_STRING_P(matchCar)) {
+        if (scm_is_string(matchCar)) {
             do_substitution(pzStr, *pStrLen, matchCar, replCar,
                             &pzNxt, pStrLen);
 
@@ -278,7 +257,7 @@ do_multi_subs(char ** ppzStr, ssize_t * pStrLen, SCM match, SCM repl)
 SCM
 ag_scm_mk_gettextable(SCM txt)
 {
-    if (AG_SCM_STRING_P(txt)) {
+    if (scm_is_string(txt)) {
         char const * pz = ag_scm2zchars(txt, "txt");
         optionPrintParagraphs(pz, false, cur_fpstack->stk_fp);
     }
@@ -303,19 +282,19 @@ ag_scm_in_p(SCM obj, SCM list)
     SCM     car;
     char const * pz1;
 
-    if (! AG_SCM_STRING_P(obj))
+    if (! scm_is_string(obj))
         return SCM_UNDEFINED;
 
-    pz1  = AG_SCM_CHARS(obj);
-    lenz = AG_SCM_STRLEN(obj);
+    pz1  = scm_i_string_chars(obj);
+    lenz = scm_c_string_length(obj);
 
     /*
      *  If the second argument is a string somehow, then treat
      *  this as a straight out string comparison
      */
-    if (AG_SCM_STRING_P(list)) {
-        if (  (AG_SCM_STRLEN(list) == lenz)
-           && (strncmp(pz1, AG_SCM_CHARS(list), lenz) == 0))
+    if (scm_is_string(list)) {
+        if (  (scm_c_string_length(list) == lenz)
+           && (strncmp(pz1, scm_i_string_chars(list), lenz) == 0))
             return SCM_BOOL_T;
         return SCM_BOOL_F;
     }
@@ -337,14 +316,14 @@ ag_scm_in_p(SCM obj, SCM list)
          *  hands it to us, it magically becomes a nested list.
          *  This unravels that.
          */
-        if (! AG_SCM_STRING_P(car)) {
+        if (! scm_is_string(car)) {
             if (ag_scm_in_p(obj, car) == SCM_BOOL_T)
                 return SCM_BOOL_T;
             continue;
         }
 
-        if (  (AG_SCM_STRLEN(car) == lenz)
-           && (strncmp(pz1, AG_SCM_CHARS(car), lenz) == 0) )
+        if (  (scm_c_string_length(car) == lenz)
+           && (strncmp(pz1, scm_i_string_chars(car), lenz) == 0) )
             return SCM_BOOL_T;
     }
 
@@ -376,15 +355,15 @@ ag_scm_join(SCM sep, SCM list)
     char const * pzSep;
     char *   pzScan;
 
-    if (! AG_SCM_STRING_P(sep))
+    if (! scm_is_string(sep))
         return SCM_UNDEFINED;
 
     sv_l_len = l_len = (int)scm_ilength(list);
     if (l_len == 0)
-        return AG_SCM_STR02SCM(zNil);
+        return scm_from_latin1_string(zNil);
 
-    pzSep   = AG_SCM_CHARS(sep);
-    sep_len = AG_SCM_STRLEN(sep);
+    pzSep   = scm_i_string_chars(sep);
+    sep_len = scm_c_string_length(sep);
     str_len = 0;
 
     /*
@@ -400,14 +379,14 @@ ag_scm_join(SCM sep, SCM list)
          *  hands it to us, it magically becomes a nested list.
          *  This unravels that.
          */
-        if (! AG_SCM_STRING_P(car)) {
+        if (! scm_is_string(car)) {
             if (car != SCM_UNDEFINED)
                 car = ag_scm_join(sep, car);
-            if (! AG_SCM_STRING_P(car))
+            if (! scm_is_string(car))
                 return SCM_UNDEFINED;
         }
 
-        str_len += AG_SCM_STRLEN(car);
+        str_len += scm_c_string_length(car);
 
         if (--l_len <= 0)
             break;
@@ -430,11 +409,11 @@ ag_scm_join(SCM sep, SCM list)
         /*
          *  This unravels nested lists.
          */
-        if (! AG_SCM_STRING_P(car))
+        if (! scm_is_string(car))
             car = ag_scm_join(sep, car);
 
-        cpy_len = AG_SCM_STRLEN(car);
-        memcpy((void*)pzScan, AG_SCM_CHARS(car), cpy_len);
+        cpy_len = scm_c_string_length(car);
+        memcpy(VOIDP(pzScan), scm_i_string_chars(car), cpy_len);
         pzScan += cpy_len;
 
         /*
@@ -442,11 +421,11 @@ ag_scm_join(SCM sep, SCM list)
          */
         if (--l_len <= 0)
             break;
-        memcpy((void*)pzScan, (void*)pzSep, sep_len);
+        memcpy(VOIDP(pzScan), VOIDP(pzSep), sep_len);
         pzScan += sep_len;
     }
 
-    return AG_SCM_STR2SCM(pzRes, str_len);
+    return scm_from_latin1_stringn(pzRes, str_len);
 }
 
 
@@ -460,10 +439,11 @@ ag_scm_join(SCM sep, SCM list)
  *
  * doc:
  *  Prefix every line in the second string with the first string.
- *  This includes empty lines, though trailing white space will
- *  be removed if the line consists only of the "prefix".
- *  Also, if the last character is a newline, then *two* prefixes will
- *  be inserted into the result text.
+ *  This includes empty lines.  Trailing white space will be removed
+ *  so if the prefix is all horizontal white space, then it will be
+ *  removed from otherwise blank lines.  Also, if the last character
+ *  is a newline, then *two* prefixes will be inserted into the result
+ *  text.
  *
  *  For example, if the first string is "# " and the second contains:
  *  @example
@@ -504,6 +484,9 @@ ag_scm_prefix(SCM prefx, SCM txt)
         r_str = scan = scribble_get((ssize_t)out_size);
     }
 
+    /*
+     * If the text starts with a newline, then do not apply
+     */
     memcpy(scan, prefix, pfx_size);
     scan += pfx_size;
     pfx_size++;
@@ -516,7 +499,7 @@ ag_scm_prefix(SCM prefx, SCM txt)
              * Trim trailing white space on the final line.
              */
             scan = SPN_HORIZ_WHITE_BACK(r_str, scan);
-            return AG_SCM_STR2SCM(r_str, scan - r_str);
+            return scm_from_latin1_stringn(r_str, scan - r_str);
 
         case NL:
             /*
@@ -564,7 +547,7 @@ ag_scm_raw_shell_str(SCM obj)
     data = ag_scm2zchars(obj, "AG Object");
 
     {
-        size_t dtaSize = AG_SCM_STRLEN(obj) + 3; /* NUL + 2 quotes */
+        size_t dtaSize = scm_c_string_length(obj) + 3; /* NUL + 2 quotes */
         pz = data-1;
         for (;;) {
             pz = strchr(pz+1, '\'');
@@ -625,7 +608,7 @@ ag_scm_raw_shell_str(SCM obj)
 
  returnString:
     {
-        SCM res = AG_SCM_STR02SCM(pzFree);
+        SCM res = scm_from_latin1_string(pzFree);
         AGFREE(pzFree);
         return res;
     }
@@ -733,11 +716,11 @@ ag_scm_sub_shell_str(SCM obj)
 SCM
 ag_scm_stack(SCM obj)
 {
-    SCM         res;
-    SCM *       pos = &res;
-    def_ent_t** ppDE;
-    def_ent_t*  pDE;
-    SCM         str;
+    SCM          res;
+    SCM *        pos = &res;
+    def_ent_t ** ppDE;
+    def_ent_t *  pDE;
+    SCM          str;
 
     res = SCM_EOL;
 
@@ -754,7 +737,7 @@ ag_scm_stack(SCM obj)
         if (pDE->de_type != VALTYP_TEXT)
             return SCM_UNDEFINED;
 
-        str  = AG_SCM_STR02SCM(pDE->de_val.dvu_text);
+        str  = scm_from_latin1_string(pDE->de_val.dvu_text);
         *pos = scm_cons(str, SCM_EOL);
         pos  = SCM_CDRLOC(*pos);
     }
@@ -783,7 +766,7 @@ ag_scm_kr_string(SCM str)
     char const * pz = ag_scm2zchars(str, "krstr");
     SCM res;
     pz  = optionQuoteString(pz, KR_STRING_NEWLINE);
-    res = AG_SCM_STR02SCM(pz);
+    res = scm_from_latin1_string(pz);
     AGFREE(pz);
     return res;
 }
@@ -814,11 +797,28 @@ ag_scm_c_string(SCM str)
     char const * pz = ag_scm2zchars(str, "cstr");
     SCM res;
     pz  = optionQuoteString(pz, C_STRING_NEWLINE);
-    res = AG_SCM_STR02SCM(pz);
+    res = scm_from_latin1_string(pz);
     AGFREE(pz);
     return res;
 }
 
+/**
+ * Map a character range for ag_scm_string_tr_x()
+ */
+static inline void
+tr_char_range(unsigned char * ch_map, unsigned char * from, unsigned char * to)
+{
+    unsigned char fs = (unsigned char)from[-2]; // "from" start char
+    unsigned char fe = (unsigned char)from[0];  // "from" end char
+    unsigned char ts = (unsigned char)to[-2];   // "to" start char
+    unsigned char te = (unsigned char)to[0];    // "to" end char
+
+    while (fs < fe) {
+        ch_map[ fs++ ] = ts;
+        if (ts < te)
+            ts++;
+    }
+}
 
 /*=gfunc string_tr_x
  *
@@ -841,9 +841,9 @@ SCM
 ag_scm_string_tr_x(SCM str, SCM from_xform, SCM to_xform)
 {
     unsigned char ch_map[ 1 << 8 /* bits-per-byte */ ];
-    int   i    = sizeof(ch_map) - 1;
-    char* from = ag_scm2zchars(from_xform, "str");
-    char* to   = ag_scm2zchars(to_xform, "str");
+    int    i    = sizeof(ch_map) - 1;
+    char * from = ag_scm2zchars(from_xform, "str");
+    char * to   = ag_scm2zchars(to_xform, "str");
 
     do  {
         ch_map[i] = (unsigned char)i;
@@ -863,18 +863,21 @@ ag_scm_string_tr_x(SCM str, SCM from_xform, SCM to_xform)
             goto map_done;
 
         case '-':
-            if ((i > 0) && (tch == '-')) {
-                unsigned char fs = (unsigned char)from[-2];
-                unsigned char fe = (unsigned char)from[0];
-                unsigned char ts = (unsigned char)to[-2];
-                unsigned char te = (unsigned char)to[0];
-                if (te != NUL) {
-                    while (fs < fe) {
-                        ch_map[ fs++ ] = ts;
-                        if (ts < te) ts++;
-                    }
-                    break;
-                }
+            /*
+             * "from" char is a hyphen.
+             * IF we are beyond the first character AND
+             *    the "to" character is a hyphen AND
+             *    there is a "from" character after the hyphen
+             *    there is a "to" character after the hyphen,
+             * THEN map a character range
+             */
+            if (  (i > 0)
+               && (tch     == '-')
+               && (from[0] != NUL)
+               && (to[0]   != NUL)) {
+                tr_char_range(ch_map, (unsigned char *)from,
+                              (unsigned char *)to);
+                break;
             }
 
         default:
@@ -882,8 +885,8 @@ ag_scm_string_tr_x(SCM str, SCM from_xform, SCM to_xform)
         }
     } map_done:;
 
-    to = C(char *, AG_SCM_CHARS(str));
-    i    = (int)AG_SCM_STRLEN(str);
+    to = C(char *, scm_i_string_chars(str));
+    i    = (int)scm_c_string_length(str);
     while (i-- > 0) {
         *to = (char)ch_map[ (int)*to ];
         to++;
@@ -906,8 +909,8 @@ ag_scm_string_tr_x(SCM str, SCM from_xform, SCM to_xform)
 SCM
 ag_scm_string_tr(SCM Str, SCM From, SCM To)
 {
-    size_t lenz  = AG_SCM_STRLEN(Str);
-    SCM    res   = AG_SCM_STR2SCM(AG_SCM_CHARS(Str), lenz);
+    size_t lenz  = scm_c_string_length(Str);
+    SCM    res   = scm_from_latin1_stringn(scm_i_string_chars(Str), lenz);
     return ag_scm_string_tr_x(res, From, To);
 }
 
@@ -938,18 +941,18 @@ ag_scm_string_substitute(SCM str, SCM Match, SCM Repl)
     ssize_t len;
     SCM     res;
 
-    if (! AG_SCM_STRING_P(str))
+    if (! scm_is_string(str))
         return SCM_UNDEFINED;
 
-    text = AG_SCM_CHARS(str);
-    len   = (ssize_t)AG_SCM_STRLEN(str);
+    text = scm_i_string_chars(str);
+    len   = (ssize_t)scm_c_string_length(str);
 
-    if (AG_SCM_STRING_P(Match))
-        do_substitution(text, len, Match, Repl, (char**)&text, &len);
+    if (scm_is_string(Match))
+        do_substitution(text, len, Match, Repl, (char **)&text, &len);
     else
-        do_multi_subs((char**)&text, &len, Match, Repl);
+        do_multi_subs((char **)&text, &len, Match, Repl);
 
-    res = AG_SCM_STR2SCM(text, (size_t)len);
+    res = scm_from_latin1_stringn(text, (size_t)len);
     return res;
 }
 
@@ -974,13 +977,13 @@ ag_scm_time_string_to_number(SCM time_spec)
     char const * pz;
     time_t  time_period;
 
-    if (! AG_SCM_STRING_P(time_spec))
+    if (! scm_is_string(time_spec))
         return SCM_UNDEFINED;
 
-    pz = AG_SCM_CHARS(time_spec);
+    pz = scm_i_string_chars(time_spec);
     time_period = parse_duration(pz);
 
-    return AG_SCM_INT2SCM((int)time_period);
+    return scm_from_int((int)time_period);
 }
 
 /**
