@@ -30,7 +30,7 @@ die() {
 }
 
 init() {
-    PS4='>tpc-${FUNCNAME}> '
+    PS4='+tpc-${FUNCNAME:-=}-$LINENO> '
     progpid=$$
     prog=`basename $0`
     progdir=`\cd \`dirname $0\` >/dev/null ; pwd`
@@ -53,7 +53,7 @@ collect_src() {
     cat 1>&8 <<- _EOF_
 	#define  AUTOOPTS_INTERNAL 1
 	#include "autoopts/project.h"
-	#define  LOCAL static
+
 	#include "ao-strs.h"
 	static char const ao_ver_string[] =
 	    "${AO_CURRENT}:${AO_REVISION}:${AO_AGE}\n";
@@ -70,7 +70,7 @@ extension_defines() {
 
     test -f tpl-config.tlib || die "tpl-config.tlib not configured"
     test -f ${top_builddir}/config.h || die "config.h missing"
-    ${GREP} 'extension-defines' tpl-config.tlib >/dev/null && return
+    ${GREP:-grep} 'extension-defines' tpl-config.tlib >/dev/null && return
 
     txt=`sed -n '/POSIX.*SOURCE/,/does not conform to ANSI C/{
 	    /^#/p
@@ -233,6 +233,9 @@ fix_guile() {
     nores='\1__noreturn__\2'
     sedex="s@${noret}@${nores}@"
 
+    echo "Patching files to remove bare 'noreturn' keyword in" \
+	 $list >&2
+
     for f in $list
     do
         g=libguile${f##*/libguile}
