@@ -3,11 +3,11 @@
 ## mdoc2man.pl -- Convert mdoc tags to man tags
 ##
 ## Author:	Harlan Stenn <stenn@ntp.org>
-##		
+##
 ##
 ##  This file is part of AutoOpts, a companion to AutoGen.
 ##  AutoOpts is free software.
-##  AutoOpts is Copyright (C) 1992-2015 by Bruce Korb - all rights reserved
+##  AutoOpts is Copyright (C) 1992-2018 by Bruce Korb - all rights reserved
 ##
 ##  AutoOpts is available under any one of two licenses.  The license
 ##  in use must be one of these two and the choice is under the control
@@ -81,9 +81,9 @@ Mdoc::def_macro( '.Ar', sub { mapwords {"\\f\\*[I-Font]$_\\f[]"} @_ } );
 Mdoc::def_macro( '.Em', sub { mapwords {"\\fI$_\\f[]"} @_ } );
 Mdoc::def_macro( '.Va', sub { mapwords {"\\fI$_\\f[]"} @_ } );
 Mdoc::def_macro( '.Sx', sub { mapwords {"\\fI$_\\f[]"} @_ } );
-Mdoc::def_macro( '.Xr', sub { "\\fC".(shift)."\\fR(".(shift).")\\f[]", @_ } );
-Mdoc::def_macro( '.Fn', sub { "\\f\\*[B-Font]".(shift)."\\fR()\\f[]" } );
-Mdoc::def_macro( '.Fn', sub { "\\fB".(shift)."\\fR()\\f[]" } );
+Mdoc::def_macro( '.Xr', sub { "\\fC".(shift)."\\f[]\\fR(".(shift).")\\f[]", @_ } );
+Mdoc::def_macro( '.Fn', sub { "\\f\\*[B-Font]".(shift)."\\f[]\\fR()\\f[]" } );
+Mdoc::def_macro( '.Fn', sub { "\\fB".(shift)."\\f[]\\fR()\\f[]" } );
 Mdoc::def_macro( '.Fx', sub { "FreeBSD", @_ } );
 Mdoc::def_macro( '.Ux', sub { "UNIX", @_ } );
 
@@ -146,7 +146,7 @@ Mdoc::set_Bl_callback(do { my $nested = 0; sub {
     if (defined $type && $type =~ /-(\w+)/ && exists $lists{$1}) {
 
         # Wrap nested lists with .RS and .RE
-        Mdoc::set_El_callback(sub { 
+        Mdoc::set_El_callback(sub {
                 return '.RE' if $nested-- > 1;
                 return '.PP';
             });
@@ -170,7 +170,7 @@ Mdoc::set_Bl_callback(do { my $nested = 0; sub {
 Mdoc::def_macro('.Bd', sub { ".br\n.in +4\n.nf" } );
 Mdoc::def_macro('.Ed', sub { ".in -4\n.fi" } );
 
-Mdoc::set_Re_callback(sub { 
+Mdoc::set_Re_callback(sub {
         my ($reference) = @_;
         <<"REF";
 $reference->{authors},
